==> grpc-grpclb-1.2.0-sources.jar: io/grpc/grpclb/LbAddressGroup.java <==
/*
 * Copyright 2016, Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *    * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *
 *    * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package io.grpc.grpclb;

import static com.google.common.base.Preconditions.checkNotNull;

import io.grpc.EquivalentAddressGroup;

/**
 * Represents a balancer address entry.
 */
class LbAddressGroup {
  private final EquivalentAddressGroup addresses;
  private final String authority;

  LbAddressGroup(EquivalentAddressGroup addresses, String authority) {
    this.addresses = checkNotNull(addresses, "addresses");
    this.authority = checkNotNull(authority, "authority");
  }

  @Override
  public boolean equals(Object other) {
    if (!(other instanceof LbAddressGroup)) {
      return false;
    }
    LbAddressGroup otherGroup = (LbAddressGroup) other;
    return addresses.equals(otherGroup.addresses) && authority.equals(otherGroup.authority);
  }

  @Override
  public int hashCode() {
    return addresses.hashCode();
  }

  EquivalentAddressGroup getAddresses() {
    return addresses;
  }

  String getAuthority() {
    return authority;
  }
}

==> grpc-grpclb-1.3.0-sources.jar: io/grpc/grpclb/LbAddressGroup.java <==
/*
 * Copyright 2016, Google Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *    * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *    * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *
 *    * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package io.grpc.grpclb;

import static com.google.common.base.Preconditions.checkNotNull;

import io.grpc.EquivalentAddressGroup;

/**
 * Represents a balancer address entry.
 */
final class LbAddressGroup {
  private final EquivalentAddressGroup addresses;
  private final String authority;

  LbAddressGroup(EquivalentAddressGroup addresses, String authority) {
    this.addresses = checkNotNull(addresses, "addresses");
    this.authority = checkNotNull(authority, "authority");
  }

  @Override
  public boolean equals(Object other) {
    if (!(other instanceof LbAddressGroup)) {
      return false;
    }
    LbAddressGroup otherGroup = (LbAddressGroup) other;
    return addresses.equals(otherGroup.addresses) && authority.equals(otherGroup.authority);
  }

  @Override
  public int hashCode() {
    return addresses.hashCode();
  }

  EquivalentAddressGroup getAddresses() {
    return addresses;
  }

  String getAuthority() {
    return authority;
  }
}
